import { InjectionKey, ComputedRef } from 'vue';
import FormModelService from './FormModelService';
import { ErrorList } from 'async-validator';
/**
 * @description
 * handle form input
 * binding formModelService with
 * use it in formItem or input like component
 * @date 2020-09-12
 * @export
 * @class FormInputService
 */
export default class FormInputService {
    static token: InjectionKey<FormInputService>;
    /**
     * @description
     * root service in FormModelService formation
     * @type {FormModelService<any>}
     * @memberof FormInputService
     */
    root: FormModelService<any>;
    /**
     * @description
     * parent item
     * @type {FormInputService}
     * @memberof FormInputService
     */
    parent: FormInputService;
    /**
     * @description
     * key list from root data or other data
     * form input service do not manage is own data
     * just get agent from root
     * @type {string[]}
     * @memberof FormInputService
     */
    keyList: string[];
    key: string;
    validateOn: 'blur' | 'change';
    errorList: ComputedRef<ErrorList>;
    get data(): any;
    set data(val: any);
    get touched(): any;
    focus: () => void;
    blur: () => void;
    constructor(key?: string, initialValue?: any, rootToken?: InjectionKey<FormModelService<any>>);
    /**
     * @description
     * bind key and keyList
     * to get the control of root data
     * @date 2020-09-12
     * @param {string} [key]
     * @memberof FormInputService
     */
    bindKey(key?: string): void;
}
