import { OverlayProps } from "../overlay_props";
import { ConnectionPositionPair } from "./position_pair";
import { PositionStrategy } from "./position_strategy";
import { CSSProperties, Ref } from 'vue';
interface Point {
    x: number;
    y: number;
}
export declare type FlexiblePositionStrategyOrigin = Element | Ref<Element | undefined> | (Point & {
    width?: number;
    height?: number;
});
/**
 * @description
 * Flexible position strategy can let your overlay
 * content flexible in a overlay wrapper dom.
 * @date 2020-09-22
 * @export
 * @class FlexiblePositionStrategy
 */
export declare class FlexiblePositionStrategy implements PositionStrategy {
    private _origin;
    private window;
    private _width;
    private _height;
    private _positionPair;
    private currentPositionedStyle;
    private subscribe?;
    private isVisible;
    constructor(_origin: FlexiblePositionStrategyOrigin, window: Window);
    setup(): OverlayProps;
    attach(): void;
    detach(): void;
    dispose(): void;
    /**
     * Sets the origin of the overlay.
     *
     * @param value New origin.
     */
    origin(value: FlexiblePositionStrategyOrigin): this;
    /**
     * Sets the position pair of the overlay.
     * In flexible overlay, you need to mark
     * two anchor points, one is the element
     * you want to anchor on it, the another
     * one is Overlay.
     * @param value New position pair.
     */
    positionPair(value: ConnectionPositionPair): this;
    /**
     * Sets the height of the overlay.
     * @param height New height.
     */
    height(height: number): this;
    /**
     * Sets the width of the overlay.
     * @param width New width.
     */
    width(width: number): this;
    private _getOverlayPoint;
    /**
     * Gets the (x, y) coordinate of a connection point on the origin based on a relative position.
     */
    private _getOriginPoint;
    /** Returns the ClientRect of the current origin. */
    private _getOriginRect;
    caculateScroll(style: Ref<CSSProperties>, originPoint: Point): void;
}
export {};
