import { Ref } from "vue";
/**
 * scroll anchor direction
 *
 * @export
 * @enum {number}
 */
export declare enum ScrollFrom {
    top = "top",
    left = "left",
    right = "right",
    bottom = "bottom",
    start = "start",
    end = "end"
}
/**
 * prossible scroll type of browser
 *
 * @export
 * @enum {number}
 */
export declare enum ScrollAxisType {
    normal = "normal",
    negated = "negated",
    inverted = "inverted"
}
/**
 *scroll to command
 *
 * @export
 * @interface ScrollToOptions
 */
export interface ScrollToOptions {
    top?: number;
    bottom?: number;
    left?: number;
    right?: number;
    start?: number;
    end?: number;
}
export default class {
    nodeRef: Ref<HTMLElement | null>;
    scrollCb: (e: Event) => void;
    private body;
    private scrollAxisType?;
    private handleScroll;
    constructor();
    /**
     * scroll to specific target
     * !never forget relative position of scrollable ref
     * !never forget param nodeRef is direct child of scrollable ref
     *
     */
    scrollToElement: (nodeRef: Ref<HTMLElement | null>) => void;
    /**
     * pre handle scroll to options
     *
     */
    scrollTo: (options: ScrollToOptions) => void;
    /**
     * handle scrollto
     *
     */
    applyScrollToOptions: (options: ScrollToOptions) => void;
    /**
     * mesure offset from an anchor
     *
     */
    mesureScrollOffset: (from: ScrollFrom) => number;
    /**
     * get the browser scroll type by dom
     *
     */
    getScrollAxisType: () => ScrollAxisType;
}
