import { Ref } from "vue";
declare type TdRender<T> = (item: T, index: number) => JSX.Element;
export interface TableColumn<T> {
    dataIndex?: string;
    header: string | JSX.Element;
    content: TdRender<T> | string;
    selected?: boolean;
    hidden?: boolean;
    order?: number;
}
/**
 * use like
 * <table>
 *    <tr>{tableModel.columns.map(el=>(<th>el.header</th>))}</tr>
 *    {tableModel.dataSource.map((el,key)=><tr>
 *       {tableModel.displayColumns.map(item=>
 *         <td>{item.dataIndex?item.content:item.content(el,key))}</td>
 *       }
 *    </tr>)}
 * </table>
 *
 * @export
 * @class
 * @template T
 */
export default class<T extends {
    [key: string]: any;
}> {
    dataSource: T[];
    columns: TableColumn<T>[];
    displayColumns: TableColumn<T>[];
    mark: () => void;
    dirty: Ref<null | undefined>;
    currentOrderKey: string;
    changeOrder: (key: string, desc?: boolean) => void;
    /**
     * hide/show column
     *
     */
    toggleSomeContent: (dataIndexs: string[], show?: boolean) => void;
    constructor(dataSource: T[], columns: TableColumn<T>[]);
}
export {};
