import { InjectionKey, Ref } from "vue";
/**
 * *handle typescript type by function
 * get a token from a function
 *
 * @export
 * @template T
 * @param {(...args: any[]) => T} func
 * @param {string} [name]
 * @returns {InjectionKey<T>}
 */
export declare function getFuncToken<T>(func: (...args: any[]) => T, name?: string): InjectionKey<T>;
/**
 * *handle typescript type by function
 * get a token from class
 *
 * @export
 * @template T
 * @param {{ new (...args: any[]): T }} constructor
 * @param {string} [name]
 * @returns {InjectionKey<T>}
 */
export declare function getClassToken<T>(constructor: {
    new (...args: any[]): T;
}, name?: string): InjectionKey<T>;
/**
 * mark a component or service to dirty
 * so that all the value will reactive once
 *
 * @export
 * @returns
 */
export declare function markDirty(): {
    dirty: Ref<null | undefined>;
    mark: () => void;
};
/**
 * sub component react to service's dirty ref
 *
 * @export
 * @param {(Ref<null | undefined>)} dirty
 * @returns
 */
export declare function reactToService(dirty: Ref<null | undefined>): Ref<null | undefined>;
